<?php
/**
 * Customizer settings definitions.
 *
 * @package Slope
 */

/**
 * Get the array of definitions for Customizer settings and controls.
 *
 * @since 1.0.0.
 *
 * @param  object $wp_customize    The Customizer instance.
 *
 * @return mixed|void
 */
function slope_customize_get_definitions( $wp_customize ) {
	$google_fonts = slope_all_font_choices();

	$wp_customize->add_panel(
		 'slope_options_panel', array(
			 'title'       => esc_html__( 'Theme Options', 'slope' ),
			 'description' => esc_html__( 'Configure your theme settings', 'slope' ),
			 'priority'    => 999,
		 )
		);

	$wp_customize->remove_control( 'display_header_text' );

	// Add selective refresh for custom header.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			 'header-image-title', array(
				 'selector'        => '.custom-header .custom-header__title',
				 'render_callback' => function() {
					 return slope_get_thememod_value( 'header-image-title' );
				 },
			 )
			);

		$wp_customize->selective_refresh->add_partial(
			 'header-image-description', array(
				 'selector'        => '.custom-header .custom-header__description',
				 'render_callback' => function() {
					 return wp_kses_post( do_shortcode( wpautop( slope_get_thememod_value( 'header-image-description' ) ) ) );
				 },
			 )
			);
	}

	$definitions = array(
		'colors'        => array(
			'title'       => esc_html__( 'Colors', 'slope' ),
			'description' => '',
			'priority'    => '',
			'options'     => array(
				'color-accent'            => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Accent', 'slope' ),
					),
				),
				'color-secondary'         => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Secondary', 'slope' ),
						'description'   => esc_html__( 'Used for section background and highlights.', 'slope' ),
					),
				),
				'color-footer-background' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Footer Background', 'slope' ),
					),
				),
				'color-footer-text'       => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'control_class' => 'WP_Customize_Color_Control',
						'label'         => esc_html__( 'Footer Text Color', 'slope' ),
					),
				),
			),
		),

		'slope_fonts'   => array(
			'title'       => esc_html__( 'Fonts', 'slope' ),
			'panel'       => 'slope_options_panel',
			'description' => sprintf(
				/* translators: Link to Google Fonts website */
				esc_html__( 'The list of Google fonts is long! You can %s before making your choices.', 'slope' ),
				sprintf(
					'<a href="%1$s" class="external-link" target="_blank">%2$s</a>',
					esc_url( 'https://fonts.google.com' ),
					esc_html__( 'preview', 'slope' )
				)
			),
			'options'     => array(
				'font-body'          => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Body', 'slope' ),
					),
				),
				'font-headers'       => array(
					'setting' => array(),
					'control' => array(
						'type'    => 'select',
						'choices' => $google_fonts,
						'label'   => esc_html__( 'Headers', 'slope' ),
					),
				),
				'google-font-subset' => array(
					'setting' => array(),
					'control' => array(
						'type'        => 'select',
						'choices'     => slope_get_google_font_subsets(),
						'label'       => esc_html__( 'Google Font Subset', 'slope' ),
						'description' => sprintf(
							/* translators: Link to Google fonts website */
							esc_html__( 'Not all fonts provide each of these subsets. Please visit the %s to see which subsets are available for each font.', 'slope' ),
							sprintf(
								'<a href="%1$s" target="_blank">%2$s</a>',
								esc_url( 'https://fonts.google.com' ),
								esc_html__( 'Google Fonts website', 'slope' )
							)
						),
					),
				),
			),
		),

		'header_image'  => array(
			'options' => array(
				'header-image-title'        => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Custom Header Title', 'slope' ),
					),
				),
				'header-image-description'  => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Custom Header Content', 'slope' ),
					),
				),
				'header-image-button-url'   => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Button URL', 'slope' ),
					),
				),
				'header-image-button-label' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Button Label', 'slope' ),
					),
				),
				'header-image-position'     => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'label'   => esc_html__( 'Content Position', 'slope' ),
						'type'    => 'select',
						'choices' => array(
							'left'   => esc_html__( 'Left', 'slope' ),
							'center' => esc_html__( 'Center', 'slope' ),
							'right'  => esc_html__( 'Right', 'slope' ),
						),
					),
				),
			),
		),

		'blog_settings' => array(
			'title'   => esc_html__( 'Blog Settings', 'slope' ),
			'panel'   => 'slope_options_panel',
			'options' => array(
				'page-sidebar'            => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'    => 'select',
						'label'   => esc_html__( 'Single Page Sidebar Position', 'slope' ),
						'choices' => array(
							'left'  => esc_html__( 'Left', 'slope' ),
							'right' => esc_html__( 'Right', 'slope' ),
							'none'  => esc_html__( 'No Sidebar', 'slope' ),
						),
					),
				),
				'single-sidebar'          => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'    => 'select',
						'label'   => esc_html__( 'Single Post Sidebar Position', 'slope' ),
						'choices' => array(
							'left'  => esc_html__( 'Left', 'slope' ),
							'right' => esc_html__( 'Right', 'slope' ),
							'none'  => esc_html__( 'No Sidebar', 'slope' ),
						),
					),
				),
				'blog-column'             => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Blog Columns', 'slope' ),
						'description' => esc_html__( 'Choose column layout for blog pages.', 'slope' ),
						'type'        => 'radio',
						'choices'     => array(
							2 => esc_html__( '2 Columns + Sidebar', 'slope' ),
							3 => esc_html__( '3 columns', 'slope' ),
							4 => esc_html__( '4 columns', 'slope' ),
						),
					),
				),
				'bool-hide-related-posts' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Hide Related Posts', 'slope' ),
						'description' => esc_html( 'Hide related posts from single posts, displayed on basis of post tags.' ),
					),
				),
				'bool-hide-post-excerpt'  => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'checkbox',
						'label'       => esc_html__( 'Hide Post Excerpt', 'slope' ),
						'description' => esc_html( 'Hide post excerpt from blog archive pages.' ),
					),
				),
				'post-excerpt-length'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'        => 'number',
						'label'       => esc_html__( 'Post Excerpt Length', 'slope' ),
						'input_attrs' => array(
							'step' => '5',
							'min'  => '10',
							'max'  => '200',
						),
					),
				),
				'fallback-blog-image'     => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Fallback Post Cover', 'slope' ),
						'control_class' => 'WP_Customize_Image_Control',
						'description'   => esc_html__( 'Provide a fallback image for post cover on single post, pages, and archive pages.', 'slope' ),
					),
				),
			),
		),

		'site_settings' => array(
			'title'   => esc_html__( 'Site Settings', 'slope' ),
			'panel'   => 'slope_options_panel',
			'options' => array(
				// 'site-width' => array(
				// 'setting' => array(
				// 'transport' => 'postMessage',
				// 'validate_callback' => 'slope_validate_site_width',
				// ),
				// 'control' => array(
				// 'type'        => 'number',
				// 'label'       => esc_html__( 'Site Width', 'slope' ),
				// 'description' => esc_html( 'Control the site width, defaults to 1400 (px).', 'slope' ),
				// 'input_attrs' => array(
				// 'step' => '10',
				// 'min'  => '1220',
				// 'max'  => '2000',
				// ),
				// ),
				// ),
				'blog-sidebar-position' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Sidebar Position', 'slope' ),
						'description' => esc_html__( 'Choose sidebar position for blog sidebar.', 'slope' ),
						'type'        => 'radio',
						'choices'     => array(
							'left'  => esc_html__( 'Left', 'slope' ),
							'right' => esc_html__( 'Right', 'slope' ),
						),
					),
				),
			),
		),

		'shop_settings' => array(
			'title'       => esc_html__( 'Shop Settings', 'slope' ),
			'panel'       => 'slope_options_panel',
			'description' => wp_kses_data( 'You can edit your <strong>WooCommerce</strong> related theme settings here.', 'slope' ),
			'options'     => array(
				'shop-column'           => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Product Columns', 'slope' ),
						'description' => esc_html__( 'Choose column layout for product listings.', 'slope' ),
						'type'        => 'radio',
						'choices'     => array(
							2 => esc_html__( '2 Columns + Sidebar', 'slope' ),
							3 => esc_html__( '3 columns', 'slope' ),
							4 => esc_html__( '4 columns', 'slope' ),
						),
					),
				),
				'shop-sidebar-position' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'       => esc_html__( 'Sidebar Position', 'slope' ),
						'description' => esc_html__( 'Choose sidebar position for shop sidebar.', 'slope' ),
						'type'        => 'radio',
						'choices'     => array(
							'left'  => esc_html__( 'Left', 'slope' ),
							'right' => esc_html__( 'Right', 'slope' ),
						),
					),
				),
				'fallback-shop-image'   => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Fallback Post Cover', 'slope' ),
						'control_class' => 'WP_Customize_Image_Control',
						'description'   => esc_html__( 'Provide a fallback image for product category post covers and shop archive page.', 'slope' ),
					),
				),
			),
		),

		'slope_404'     => array(
			'title'   => esc_html__( '404 Error Page', 'slope' ),
			'panel'   => 'slope_options_panel',
			'options' => array(
				'error-cover-image'      => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'label'         => esc_html__( 'Page Background', 'slope' ),
						'control_class' => 'WP_Customize_Image_Control',
					),
				),
				'error-page-title'       => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Title', 'slope' ),
					),
				),
				'error-page-description' => array(
					'setting' => array(
						'transport' => 'refresh',
					),
					'control' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Description', 'slope' ),
					),
				),
			),
		),

		'slope_footer'  => array(
			'title'       => esc_html__( 'Footer', 'slope' ),
			'description' => '',
			'panel'       => 'slope_options_panel',
			'options'     => array(
				'html-footer-text' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'text',
						'label' => esc_html__( 'Footer Text', 'slope' ),
					),
				),
				'bool-hide-credit' => array(
					'setting' => array(
						'transport' => 'postMessage',
					),
					'control' => array(
						'type'  => 'checkbox',
						'label' => esc_html__( 'Hide theme byline', 'slope' ),
					),
				),
			),
		),

	);

	/**
	 * Filter the control definitions for the Customizer.
	 *
	 * '[section_id]' => array(
	 *     'title' => esc_html__( '[Section Title]', 'slope' ),
	 *     'description' => esc_html__( '[Section description]', 'slope' ),
	 *     'options' => array(
	 *         '[setting-id]' => array(
	 *             'setting' => array(
	 *                 [setting-parameter] => [value]
	 *             ),
	 *            'control' => array(
	 *                 [control-parameter] => [value]
	 *             ),
	 *         ),
	 *    ),
	 * ),
	 *
	 * @since 1.0.0.
	 *
	 * @param array    $definitions    The array containing all of the Customizer definitions.
	 */
	$definitions = apply_filters( 'slope_customizer_definitions', $definitions );

	return $definitions;
}
