<?php
/**
 * Jetpack Compatibility File
 *
 * @link https://jetpack.com/
 *
 * @package Slope
 */

/**
 * Jetpack setup function.
 *
 * See: https://jetpack.com/support/infinite-scroll/
 * See: https://jetpack.com/support/responsive-videos/
 */
function slope_jetpack_setup() {
	// Add theme support for Infinite Scroll.
	add_theme_support(
		'infinite-scroll', array(
			'container' => 'main',
			'render'    => 'slope_infinite_scroll_render',
			'footer'    => 'page',
		)
	);

	// Add theme support for Responsive Videos.
	add_theme_support( 'jetpack-responsive-videos' );

	// Add theme support for Social Menu.
	add_theme_support( 'jetpack-social-menu' );

	// Add theme support for Testimonials.
	add_theme_support( 'jetpack-testimonial' );

	// Add theme support for Content Options.
	add_theme_support(
		'jetpack-content-options', array(
			'author-bio'   => true,
			'post-details' => array(
				'stylesheet' => 'slope-style',
				'date'       => '.posted-on',
				'categories' => '.cat-links',
				'tags'       => '.tags-links',
				'author'     => '.byline',
			),
		)
	);
}
add_action( 'after_setup_theme', 'slope_jetpack_setup' );

/**
 * Custom render function for Infinite Scroll.
 */
function slope_infinite_scroll_render() {
	while ( have_posts() ) {
		the_post();
		if ( is_search() ) :
			get_template_part( 'template-parts/content', 'search' );
		else :
			get_template_part( 'template-parts/content', get_post_format() );
		endif;
	}
}

/**
 * Remove Jetpack's Related Posts module from WooCommerce single page.
 *
 * @param array $options Jetpack related posts options.
 * @return array
 */
function slope_exclude_jetpack_related_from_products( $options ) {
	if ( is_product() ) {
		$options['enabled'] = false;
	}

	return $options;
}

add_filter( 'jetpack_relatedposts_filter_options', 'slope_exclude_jetpack_related_from_products' );

/**
 * Author Bio Avatar Size.
 */
function slope_author_bio_avatar_size() {
	return 150; // in px.
}
add_filter( 'jetpack_author_bio_avatar_size', 'slope_author_bio_avatar_size' );

/**
 * Removed Subtitles support for Jetpack Testimonials.
 *
 * @return void
 */
function slope_remove_subtitles_support() {
	remove_post_type_support( 'jetpack-testimonial', 'subtitles' );
}
add_action( 'init', 'slope_remove_subtitles_support' );
