<?php
/**
 * Page: Contributors Widget
 *
 * @package Slope
 */

if ( ! class_exists( 'Slope_Widget_Contributors' ) ) :
	/**
	 * Display a list of all site contributors who published at least one post.
	 *
	 * @package Slope
	 */
	class Slope_Widget_Contributors extends Slope_Widget {
		/**
		 * Constructor
		 */
		public function __construct() {
			$this->widget_id          = 'slope_contributors';
			$this->widget_description = esc_html__( 'Display a list of all site contributors who published at least one post.', 'slope' );
			$this->widget_name        = esc_html__( 'Slope Section: Contributors', 'slope' );
			$this->widget_areas       = array( 'widget-area-page' ); // Valid widget areas.
			$this->widget_notice      = __( 'Add this widget only in "Page" widget area.', 'slope' );
			$this->settings           = array(
				'title' => array(
					'type'  => 'text',
					'std'   => 'Our Contributors',
					'label' => esc_html__( 'Title:', 'slope' ),
				),
				'subtitle' => array(
					'type'  => 'text',
					'std'   => '',
					'label' => esc_html__( 'Subtitle:', 'slope' ),
				),
				'is_centered' => array(
					'type' => 'checkbox',
					'std'  => 0,
					'label' => __( 'Center Content', 'slope' ),
				),
				'section_padding' => array(
					'type'        => 'select',
					'std'         => 'standard',
					'label'       => esc_html__( 'Section padding:', 'slope' ),
					'options'     => array(
						'100px' => esc_html__( 'Standard', 'slope' ),
						'50px'  => esc_html__( 'Half', 'slope' ),
						'0'     => esc_html__( 'None', 'slope' ),
					),
				),
				'padding_description' => array(
					'type' => 'description',
					'std'  => esc_html__( 'Determines top and bottom padding for the section.', 'slope' ),
				),
			);

			parent::__construct();
		}

		/**
		 * Output the widget content on the page.
		 *
		 * @since 1.0.0
		 *
		 * @param array $args Display arguments including 'before_title', 'after_title', 'before_widget', and 'after_widget'.
		 * @param array $instance Settings for the current widget instance.
		 */
		public function widget( $args, $instance ) {
			// Check widget areas context.
			if ( ! is_singular( 'page' ) ) {
				echo $this->widget_areas_notice(); // WPCS: XSS ok.

				return false;
			}

			$title           = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
			$subtitle        = isset( $instance['subtitle'] ) ? esc_attr( $instance['subtitle'] ) : false;
			$is_centered     = isset( $instance['is_centered'] ) ? esc_attr( $instance['is_centered'] ) : false;
			$section_padding = isset( $instance['section_padding'] ) ? esc_attr( $instance['section_padding'] ) : '100px';

			echo $args['before_widget']; // WPCS: XSS ok.
			?>

			<style type="text/css">
				#<?php echo esc_html( $this->id ); ?> {
					padding: <?php echo esc_html( $section_padding ); ?> 0;
				}
			</style>

			<section class="container<?php if ( $is_centered ) echo ' home-widget--centered'; ?>">
				<div class="home-widget-section-title">
					<?php if ( $title ) echo $args['before_title'] . $title . $args['after_title']; // WPCS: XSS ok, sanitization ok. ?>

					<?php if ( $subtitle ) : ?>
					<p class="home-widget-subtitle"><?php echo esc_attr( $subtitle ); ?></p>
					<?php endif; ?>
				</div>

				<div class="contributors-list">
					<?php slope_list_authors(); ?>
				</div>
			</section>

			<?php
			echo $args['after_widget']; // WPCS: XSS ok.
		}

		/**
		 * Registers the widget with the WordPress Widget API.
		 *
		 * @return mixed
		 */
		public static function register() {
			register_widget( __CLASS__ );
		}
	}
endif;

add_action( 'widgets_init', array( 'Slope_Widget_Contributors', 'register' ) );
