<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 *
 * @link https://codex.wordpress.org/Template_Hierarchy
 *
 * @package Slope
 */

$container_class = slope_blog_columns_class();
$fallback_image  = slope_blog_fallback_image();

get_header(); ?>

	<?php if ( ( is_front_page() || is_home() ) && false !== $fallback_image ) : ?>
	<div class="post-cover-section" style="background-image: url(<?php echo esc_url( $fallback_image ); ?>)"></div>
	<?php endif; ?>

	<div class="container <?php echo esc_attr( $container_class ); ?>">
		<div id="primary" class="content-area">
			<main id="main" class="site-main" role="main">

				<?php if ( is_front_page() || is_home() ) : ?>
				<header class="page-header archive-header background-secondary">
					<h1 class="page-title"><?php esc_html_e( 'Blog', 'slope' ); ?></h1>
				</header><!-- .page-header -->
				<?php endif; ?>

				<div class="grid" data-columns>

					<?php
					if ( have_posts() ) :

						if ( is_home() && ! is_front_page() ) :
							?>
							<header>
								<h1 class="page-title screen-reader-text"><?php single_post_title(); ?></h1>
							</header>

						<?php
						endif;

						/* Start the Loop */
						while ( have_posts() ) :
							the_post();

							/*
							* Include the Post-Format-specific template for the content.
							* If you want to override this in a child theme, then include a file
							* called content-___.php (where ___ is the Post Format name) and that will be used instead.
							*/
							get_template_part( 'template-parts/content', get_post_format() );

						endwhile;

					else :

						get_template_part( 'template-parts/content', 'none' );

					endif;
					?>

				</div>

				<?php get_template_part( 'template-parts/content', 'pagination' ); ?>

			</main><!-- #main -->
		</div><!-- #primary -->

		<?php get_sidebar( 'blog' ); ?>
	</div>

<?php
get_footer();
