/* global jQuery, slopeCustomizerSettings */

( function ( $ ) {
	'use strict';

	/**
     * Font Choices
     */
	const fontChoices = {
		cache: {},

		init: function () {
			fontChoices.cache.options = {};
			$.each( slopeCustomizerSettings.fontOptions, function ( index, key ) {
				fontChoices.cache.options[key] = $( 'select', '#customize-control-' + key );
			} );

			// Insert
			fontChoices.insertChoices();
		},

		// Insert the HTML into each font family select
		insertChoices: function () {
			$.each( fontChoices.cache.options, function ( key, element ) {
				element.chosen( {
					no_results_text: slopeCustomizerSettings.chosen_no_results_fonts,
					search_contains: true,
					width:           '100%',
				} );
			} );
		},
	};

	// Load font choices after Customizer initialization is complete.
	$( document ).ready( function () {
		fontChoices.init();
	} );

	wp.customize( 'site-width', function ( setting ) {
		setting.validate = function ( value ) {
			let code, notification;
			let year = parseInt( value, 10 );

			code = 'required';
			if ( isNaN( year ) ) {
				notification = new wp.customize.Notification( code, { message: slopeCustomizerSettings.l10n.required } );
				setting.notifications.add( code, notification );
			} else {
				setting.notifications.remove( code );
			}

			if ( isNaN( year ) ) {
				return value;
			}

			code = 'width_too_big';
			if ( year > 2000 ) {
				notification = new wp.customize.Notification( code, { message: slopeCustomizerSettings.l10n.too_big } );
				setting.notifications.add( code, notification );
			} else {
				setting.notifications.remove( code );
			}

			code = 'width_too_small';
			if ( year < 1220 ) {
				notification = new wp.customize.Notification( code, { message: slopeCustomizerSettings.l10n.too_small } );
				setting.notifications.add( code, notification );
			} else {
				setting.notifications.remove( code );
			}

			return value;
		};
	} );

	// Only show Shop page Color & Opacity controls, if an image is selected.
	wp.customize( 'bool-hide-post-excerpt', function ( setting ) {
		wp.customize.control( 'post-excerpt-length', function ( control ) {
			let visibility = function () {
				if ( setting.get() >= 1 ) {
					control.container.slideUp( 180 );
				} else {
					control.container.slideDown( 180 );
				}
			};

			visibility();
			setting.bind( visibility );
		} );
	} );

}( jQuery ) );
