/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

/* global wp */

( function ( $, api ) {

	// Site title and description.
	api( 'blogname', function ( setting ) {
		setting.bind( function ( value ) {
			$( '.site-title a' ).text( value );
		} );
	} );
	api( 'blogdescription', function ( setting ) {
		setting.bind( function ( value ) {
			$( '.site-description' ).text( value );
		} );
	} );

	// Header text color.
	api( 'header_textcolor', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value !== 'blank' ) {
				$( '.custom-header' ).css( 'color', value );
			}
		} );
	} );

	api( 'header-image-position', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value === 'left' ) {
				$( '.custom-header__content' ).removeClass( 'align-center align-right' ).addClass( 'align-left' );
			} else if ( value === 'center' ) {
				$( '.custom-header__content' ).removeClass( 'align-left align-right' ).addClass( 'align-center' );
			} else if ( value === 'right' ) {
				$( '.custom-header__content' ).removeClass( 'align-left align-center' ).addClass( 'align-right' );
			}
		} );
	} );

	// Toggle Site byline visibility
	api( 'bool-hide-credit', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value === true ) {
				$( '.site-credits' ).hide();
			} else if ( value === false ) {
				$( '.site-credits' ).show();
			}
		} );
	} );
	api( 'html-footer-text', function ( setting ) {
		setting.bind( function ( value ) {
			$( '.site-copyright' ).text( value );
		} );
	} );

	api( 'color-accent', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value !== 'blank' ) {
				$( 'body' ).get(0).style.setProperty( '--slope-color-accent', value );
			}
		} );
	} );
	api( 'color-secondary', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value !== 'blank' ) {
				$( 'body' ).get(0).style.setProperty( '--slope-color-secondary', value );
			}
		} );
	} );
	api( 'color-footer-text', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value !== 'blank' ) {
				$( 'body' ).get(0).style.setProperty( '--slope-color-footer', value );
			}
		} );
	} );
	api( 'color-footer-background', function ( setting ) {
		setting.bind( function ( value ) {
			if ( value !== 'blank' ) {
				$( 'body' ).get(0).style.setProperty( '--slope-background-footer', value );
			}
		} );
	} );

	api( 'site-width', function ( setting ) {
		setting.bind( function ( value ) {
			document.querySelector( 'body' ).style.setProperty( '--slope-site-width', value + 'px' );
		} );
	} );

}( jQuery, wp.customize ) );
