/* eslint-disable */
( function ( $ ) {
	const slope = {
		cache: {
			$document: $( document ),
			$window:   $( window ),
		},

		init() {
			this.bindEvents();
			let self = this;

			self.cache.$document.ready( function () {
				self.skipLinkFocusFix();
			} );
		},

		bindEvents() {
			let self = this;

			self.wooHoverEffect();

			// open mobile menu
			$( '.js-toggle-menu' ).click( function ( e ) {
				e.preventDefault();
				$( '.mobile-navigation' ).slideToggle();
				$( this ).toggleClass( 'open' );
			} );

			self.cache.$window.on( 'load', function() {
				self.wooResize();
			} );

			self.cache.$window.on( 'resize', self.debounce( self.wooResize, 200 ) );
		},

		wooHoverEffect() {
			if ( typeof woocommerce_params !== 'object' || typeof imagesLoaded !== 'function' || ! $( 'body' ).hasClass( 'woocommerce' ) ) {
				return;
			}

			$( '#container' ).imagesLoaded( function () {
				$( '.products img.size-shop_catalog' ).each( function ( i, img ) {
					$( this ).wrap( '<div class="woo-image-wrapper"></div>' );
					$( this ).parent().css( 'height', img.clientHeight );
				} );
			} );

		},

		wooResize() {
			if ( typeof woocommerce_params !== 'object' || typeof imagesLoaded !== 'function' || ! $( 'body' ).hasClass( 'woocommerce' ) ) {
				return;
			}

			$( 'ul.products' ).imagesLoaded( function () {
				$( '.products img.size-shop_catalog' ).each( function ( i, img ) {
					$( this ).parent( '.woo-image-wrapper' ).css( 'height', img.clientHeight );
				} );
			} );
		},

		/**
		 * Throttles an action.
		 *
		 * Taken from Underscore.js.
		 *
		 * @link    http://underscorejs.org/#debounce
		 *
		 * @param   func
		 * @param   wait
		 * @param   immediate
		 * @returns {Function}
		 */
		debounce( func, wait, immediate ) {
			let timeout, args, context, timestamp, result;
			return function () {
				context = this;
				args = arguments;
				timestamp = new Date();
				const later = function () {
					let last = ( new Date() ) - timestamp;
					if ( last < wait ) {
						timeout = setTimeout( later, wait - last );
					} else {
						timeout = null;
						if ( ! immediate ) {
							result = func.apply( context, args );
						}
					}
				};
				let callNow = immediate && ! timeout;
				if ( ! timeout ) {
					timeout = setTimeout( later, wait );
				}
				if ( callNow ) {
					result = func.apply( context, args );
				}
				return result;
			};
		},

		/**
		 * @link https://github.com/Automattic/_s/blob/dfd8a0e92171fbef6fdf66eb724db046b3448967/js/skip-link-focus-fix.js
		 *
		 * @since 1.0.0.
		 */
		skipLinkFocusFix: function () {
			let isIe = /(trident|msie)/i.test( navigator.userAgent );

			if ( isIe && document.getElementById && window.addEventListener ) {
				window.addEventListener( 'hashchange', function () {
					let id = location.hash.substring( 1 ),
						element;

					if ( ! ( /^[A-z0-9_-]+$/.test( id ) ) ) {
						return;
					}

					element = document.getElementById( id );

					if ( element ) {
						if ( ! ( /^(?:a|select|input|button|textarea)$/i.test( element.tagName ) ) ) {
							element.tabIndex = - 1;
						}

						element.focus();
					}
				}, false );
			}
		},
	};

	slope.init();
}( jQuery ) );
